==> mirza_pro-1.4.zip: mirza_pro-1.4/README.md <==
## 🎉 پروژه نسخه پرو، اوپن‌سورس شد!
نسخه‌ی **Pro** این پروژه اکنون به‌صورت **اوپن‌سورس** در دسترس است.  
از مشارکت، پیشنهادها و همکاری شما برای توسعه‌ی بهتر پروژه استقبال می‌کنیم 🤝

---

## ✏️ مشکلات رایجی که رفع شده

#### ⦁ ✅ حل مشکل جابجایی کیبوردها در پنل وب
#### ⦁ ✅ رفع مشکل مینی اپ
#### ⦁ ✅ رفع مشکل ربات نمایندگی
#### ⦁ ✅ رفع مشکل وب سرویس ارز
#### ⦁ ✅ اصلاح قیمت‌گذاری استارز با استفاده از نرخ ثابت دلار آمریکا به جای TON
#### ⦁ ✅ رفع مشکل رفع هشدار تبدیل ضمنی float به int در PHP 8.2+ (حل مشکل نمایش سرویس ها در WebApp)
#### ⦁ ✅ رفع مشکل ایجاد تاپیک‌های ناقص
#### ⦁ ✅ رفع خطای کیبورد در ربات‌های فروشندگان(نماینده ها)
#### ⦁ ✅ رفع مشکل لینک پیکربندی دستی (آزمایش شده روی پنل ثنایی 3x-ui)

---
### ✏️[اموزش رفع مشکلات رایج](https://github.com/ExploitNet/mirza_pro/blob/main/README2.md)
---

### 💖 حمایت از پروژه
اگر این پروژه برای شما مفید بوده،  
می‌توانید از طریق لینک زیر کمک کنید:

👉 [حمایت از پروژه در NowPayments](https://nowpayments.io/donation/permiumbotmirza)

---

⭐ لطفاً پروژه را **Star** کنید تا دیگران هم آن را پیدا کنند!

---

## 🎉 The Pro Version of the Project is Now Open Source!
The **Pro** version of this project is now officially **open-sourced**!  
We welcome your contributions, suggestions, and collaboration to help it grow 🤝

---

### 💖 Support the Project
If you find this project useful,  
you can support it through the link below:

👉 [Support the Project on NowPayments](https://nowpayments.io/donation/permiumbotmirza)

---

⭐ Don’t forget to **Star** the repository to help others discover it!

==> mirza_pro-1.5.zip: mirza_pro-1.5/README.md <==
## 🎉 پروژه نسخه پرو، اوپن‌سورس شد!
نسخه‌ی **Pro** این پروژه اکنون به‌صورت **اوپن‌سورس** در دسترس است.  
از مشارکت، پیشنهادها و همکاری شما برای توسعه‌ی بهتر پروژه استقبال می‌کنیم 🤝

 ![GitHub Repo stars](https://img.shields.io/github/stars/ExploitNet/mirza_pro?style=flat&label=Stars%20%E2%AD%90)

---
#### لینک گروه موقت گزارش باگ : 
https://t.me/+NABuHliyQrIzZGI0

---

## ✏️ مشکلات رایجی که رفع شده

#### ⦁ ✅ حل مشکل جابجایی کیبوردها در پنل وب
#### ⦁ ✅ رفع مشکل مینی اپ
#### ⦁ ✅ رفع مشکل ربات نمایندگی
#### ⦁ ✅ رفع مشکل وب سرویس ارز
#### ⦁ ✅ اصلاح قیمت‌گذاری استارز با استفاده از نرخ ثابت دلار آمریکا به جای TON
#### ⦁ ✅ رفع مشکل رفع هشدار تبدیل ضمنی float به int در PHP 8.2+ (حل مشکل نمایش سرویس ها در WebApp)
#### ⦁ ✅ رفع مشکل ایجاد تاپیک‌های ناقص
#### ⦁ ✅ رفع خطای کیبورد در ربات‌های فروشندگان(نماینده ها)
#### ⦁ ✅ رفع مشکل لینک پیکربندی دستی (آزمایش شده روی پنل ثنایی 3x-ui)

---
### ✏️[اموزش رفع مشکلات رایج](https://github.com/ExploitNet/mirza_pro/blob/main/README2.md)
---

### 💖 حمایت از پروژه
اگر این پروژه برای شما مفید بوده،  
می‌توانید از طریق لینک زیر کمک کنید:

👉 [حمایت از پروژه در NowPayments](https://nowpayments.io/donation/permiumbotmirza)

---

⭐ لطفاً پروژه را **Star** کنید تا دیگران هم آن را پیدا کنند!

---

## 🎉 The Pro Version of the Project is Now Open Source!
The **Pro** version of this project is now officially **open-sourced**!  
We welcome your contributions, suggestions, and collaboration to help it grow 🤝

---

### 💖 Support the Project
If you find this project useful,  
you can support it through the link below:

👉 [Support the Project on NowPayments](https://nowpayments.io/donation/permiumbotmirza)

---

⭐ Don’t forget to **Star** the repository to help others discover it!
